@@ -3,7 +3,7 @@ package Catalyst::Authentication::AuthTkt;
 use warnings;
 use strict;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 NAME
 
@@ -29,6 +29,10 @@ Catalyst::Authentication::AuthTkt - shim for Apache::AuthTkt
                 class AuthTkt
                 
                 cookie_name auth_tkt
+
+                # if ignore_ip is on in your login script, set this
+                ignore_ip 1
+                use_req_address 0.0.0.0
                 
                 # either the path to your Apache .conf file
                 #conf path/to/httpd.conf
